@@ -11,10 +11,10 @@ function(x, ...)
   print(eigen.val)
   cat("\n")
   
-  loadmat <- t(sapply(x$cat.loadings, function(xx) (xx[1,])))
+  loadmat <- t(sapply(x$loadings, function(xx) (xx[1,])))
   if (x$ndim == 1) loadmat <- t(loadmat)
   colnames(loadmat) <- paste("D", 1:x$ndim, sep = "")
-  cat("Loadings (first solution only):\n")
+  cat("Variable Loadings:\n")
   print(loadmat)
   cat("\n")
   invisible(x)
